@@ -52,15 +52,17 @@
 #' `summary()`, and `mean()`.
 #'
 #' - `print()`: prints a single result, by default the first adjusted rate.
-#' Others can be printed by passing the `pos` input. e.g. `print(x, pos = 2)`
+#' Others can be printed by passing the `pos` input. e.g. `print(x, pos = 2)`.
+#' See `help("print.adjust_rate.ft")`.
 #'
 #' - `summary()`: prints summary table of all results and metadata, or those
 #' specified by the `pos` input. e.g. `summary(x, pos = 1:5)`. The summary can
-#' be exported as a separate dataframe by passing `export = TRUE`.
+#' be exported as a separate dataframe by passing `export = TRUE`. See
+#' `help("summary.adjust_rate.ft")`.
 #'
 #' - `mean()`: calculates the mean of all adjusted rates, or those specified by
 #' the `pos` input. e.g. `mean(x, pos = 1:5)` The mean can be exported as a
-#' separate value by passing `export = TRUE`.
+#' separate value by passing `export = TRUE`. See `help("mean.adjust_rate.ft")`.
 #'
 #' ## More
 #'
@@ -140,14 +142,14 @@ adjust_rate.ft <- function(x, by) {
 
   # Validate inputs ---------------------------------------------------------
 
-  if(!is.numeric(x) && class(x) != "calc_rate.ft")
+  if(!is.numeric(x) && !inherits(x, "calc_rate.ft"))
     stop("adjust_rate.ft: 'x' must be numeric or 'calc_rate.ft' object.")
 
-  if(!is.numeric(by) && class(by) != "calc_rate.ft")
+  if(!is.numeric(by) && !inherits(by, "calc_rate.ft"))
     stop("adjust_rate.ft: 'by' must be numeric or 'calc_rate.ft' object.")
 
   # if both crft objs, check flowrate is equal
-  if(class(x) ==  "calc_rate.ft" && class(by) == "calc_rate.ft"){
+  if(inherits(x, "calc_rate.ft") && inherits(by, "calc_rate.ft")){
     flowrate_equal <- x$inputs$flowrate == by$inputs$flowrate
     if(!flowrate_equal)
       stop("adjust_rate.ft: 'x' and by' input rates have been calculated using different 'flowrates'! \nBackground adjustments should be determined at the same flowrate. \nIf you still want to proceed, you can enter the 'by' adjustment as a value.")
@@ -229,6 +231,7 @@ adjust_rate.ft <- function(x, by) {
 #' @param x adjust_rate.ft object
 #' @param pos integer. Which result to print.
 #' @param ... Pass additional inputs
+#' @keywords internal
 #' @return Print to console. No returned value.
 #' @export
 print.adjust_rate.ft <- function(x, pos = 1, ...) {
@@ -254,6 +257,7 @@ print.adjust_rate.ft <- function(x, pos = 1, ...) {
 #' @param pos integer(s). Which summary row(s) to print.
 #' @param export logical. Export summary table as data frame.
 #' @param ... Pass additional inputs
+#' @keywords internal
 #' @return Print to console. No returned value.
 #' @export
 #' @importFrom data.table data.table
@@ -288,6 +292,7 @@ summary.adjust_rate.ft <- function(object, pos = NULL, export = FALSE, ...) {
 #' @param pos integer(s). Which result(s) to average.
 #' @param export logical. Export averaged values as single value.
 #' @param ... Pass additional inputs
+#' @keywords internal
 #' @return Print to console. No returned value.
 #' @export
 mean.adjust_rate.ft <- function(x, pos = NULL, export = FALSE, ...){
@@ -322,6 +327,7 @@ mean.adjust_rate.ft <- function(x, pos = NULL, export = FALSE, ...){
 #' Plot adjust_rate.ft objects
 #' @param x adjust_rate.ft object
 #' @param ... Pass additional plotting parameters
+#' @keywords internal
 #' @return A plot. No returned value.
 #' @export
 plot.adjust_rate.ft <- function(x, ...){
